@@ -1,16 +1,17 @@
 import os
 import re
+import copy
 import subprocess
 from typing import List, Dict, Mapping, Text
 from itertools import zip_longest
 
 from jinja2 import Template, DebugUndefined
-from loguru import logger
 
-from aomaker import utils
+from aomaker.utils import utils
 from aomaker.make_api import make_api_file_from_yaml
 from aomaker.models import YamlTestcase
 from aomaker.template import Template as Temp
+from aomaker._log import logger
 
 
 class YamlParse:
@@ -24,18 +25,17 @@ class YamlParse:
         self.api_datas = {}
 
     def make_ao_file(self):
-        logger.info(f"Start to make ao file...")
-        req_data_list = self.steps
+        logger.info(f"开始生成ao文件...")
+        req_data_list = copy.deepcopy(self.steps)
         req_data_list = utils.distinct_req(req_data_list)
         # 生成ao文件
         make_api_file_from_yaml(req_data_list)
-        logger.info(f"All done!")
+        logger.info(f"全部完成!")
 
     def render_ao_file(self):
-        logger.info(f"Start to render ao file...")
+        logger.info(f"开始渲染ao文件...")
         root_dir = os.getcwd()
-        service_dir = os.path.join(root_dir, 'service')
-        service_api_dir = os.path.join(service_dir, 'service_api')
+        apis_dir = os.path.join(root_dir, 'apis')
         # 2.遍历steps
         module_flag_list = list()
         step_len = len(self.steps)
@@ -47,27 +47,29 @@ class YamlParse:
             method_name = step.get('method_name')
             data = req_data.get('data')
             json_data = req_data.get('json')
-            module = os.path.join(service_api_dir, f'{class_name}.py')
+            dependent_params = step.get('dependent_params')
+            module = os.path.join(apis_dir, f'{class_name}.py')
             if data:
                 params = data.get('params')
                 render_content = params if params else data
-                self._render_ao(module, method_name, render_content)
+                # print(render_content)
+                self._render_ao(module, method_name, render_content, dependent_params)
             if json_data:
-                self._render_ao(module, method_name, json_data)
+                self._render_ao(module, method_name, json_data, dependent_params)
             if module not in module_flag_list:
                 module_flag_list.append(module)
             if step_len - 1 == index:
                 for module in module_flag_list:
-                    logger.info(f'render {module} successfully!')
+                    logger.info(f'渲染 {module} 成功!')
                     try:
                         # 有些操作系统可能会出现文件找不到的报错，需要加shell=True这个参数
                         subprocess.run(fr'black {module}')
                     except Exception:
                         os.system(fr'black {module}')
-        logger.info(f"All done!")
+        logger.info(f"全部渲染完成!")
 
     def make_testcase_file(self):
-        logger.info(f"Start to make scenario testcase file...")
+        logger.info(f"开始生成用例文件...")
         class_name = self.testcase_class_name
         testcase_name = self.testcase_name
         description = self.description
@@ -100,11 +102,8 @@ class YamlParse:
             ao_class_list.append(ao['class_name'])
             ao_method['ao'] = ao['class_name']
             ao_method['method'] = ao['method_name']
-            is_extract = ao.get('extract')
             is_assert = ao.get('assert')
             is_data_driven = ao.get('data_driven')
-            if is_extract:
-                ao_method['extract'] = is_extract
             if is_assert:
                 ao_method['assert'] = self._handle_assert(is_assert)
             if is_data_driven:
@@ -124,7 +123,9 @@ class YamlParse:
                 ao['test_data'] = True
                 ao['assert'] = self._handle_assert(is_assert)
                 self._prepare_api_testcase_data(ao, call_ao_list, api_render_data, new_call_ao_list)
-            call_ao_list.append(ao_method)
+            dep_apis = remove_dependent_api(ao_list)
+            if {"module": ao_method['ao'], "api": ao_method['method']} not in dep_apis:
+                call_ao_list.append(ao_method)
         render_data = dict()
         if api_datas:
             # 生成单接口数据文件
@@ -152,7 +153,7 @@ class YamlParse:
         #     # 不支持追加用例
         #     logger.warning(f'make {testcase_file_path} failed, the file already exists!')
 
-        logger.info('All done!')
+        logger.info('用例文件已全部生成!')
 
     @staticmethod
     def _prepare_api_testcase_data(ao, call_ao_list, api_render_data, new_call_ao_list):
@@ -203,7 +204,6 @@ class YamlParse:
         else:
             api_render_data.update(
                 {ao['class_name']: {ao['method_name']: [ao], 'import_list': [ao['class_name']]}})
-            # set(api_render_data[ao['class_name']][ao['method_name']])
 
     @staticmethod
     def _make_api_testcase_file(api_render_data, test_api_dir):
@@ -271,10 +271,12 @@ class YamlParse:
 
     @staticmethod
     def _write_api_data(key, value, api_data_dir):
+        logger.info("开始生成YAML测试数据文件...")
         yaml_file = f'{api_data_dir}\\{key}.yaml'
         # 不覆盖同名文件
         if not os.path.exists(yaml_file):
             utils.dump_yaml({key: value}, yaml_file)
+        logger.info(f"YAML测试数据文件：{yaml_file} 已生成！")
 
     @staticmethod
     def _write_scenario_data(class_name, testcase_name, test_step_datas, scenario_data_file_path):
@@ -308,7 +310,7 @@ class YamlParse:
             assert_dict = dict()
             comparator = list(content_dict.keys())[0]
             assert_data: list = content_dict.get(comparator)
-            assert_dict['comparator'] = comparator
+            assert_dict['comparator'] = "assert_" + comparator
             assert_dict['expr'] = assert_data[0]
             assert_dict['expect'] = assert_data[-1]
             # 判断jsonpath是否有index，没有就默认为0
@@ -319,35 +321,40 @@ class YamlParse:
             new_assert_content.append(assert_dict)
         return new_assert_content
 
-    def _render_ao(self, module, method_name, content):
+    def _render_ao(self, module, method_name, content, dependent_params: List):
         with open(module) as f:
             template = f.read()
             if f'{{{{ {method_name}_params }}}}' in template:
                 temp = Template(template, undefined=DebugUndefined)
                 data = temp.render({f'{method_name}_params': content})
-                new_data = self.__replace_params(data)
+                new_data = self.__replace_params(data, dependent_params)
                 with open(module, mode='w+') as f:
                     f.write(new_data)
 
     @staticmethod
-    def __replace_params(data: str):
-        str_with_mark: list = re.findall('(\$.*?\$)', data)
-        str_without_mark: list = re.findall('\$(.*?)\$', data)
-        for replace_mark, replace_value in zip(str_with_mark, str_without_mark):
-            if '.' in replace_value:
-                value_list = replace_value.split('.')
-                # 处理测试数据
-                if value_list[0].lower() == 'test':
-                    replace_value = f"test_data['{value_list[1]}']"
+    def __replace_params(data: str, dependent_params: List):
+        # 有依赖参数才进行替换
+        if dependent_params:
+            str_with_mark: list = re.findall('(\$\w*?\$)', data)
+            str_without_mark: list = re.findall('\$(\w*?)\$', data)
+            for replace_mark, replace_value in zip(str_with_mark, str_without_mark):
                 # 处理依赖参数
-                else:
-                    replace_value = f'getattr(self.pp.{value_list[0]}, "{value_list[1]}")'
+                for dep in dependent_params:
+                    var = dep.get('params')
+                    if var == replace_value:
+                        jsonpath_expr = dep.get('jsonpath')
+                        expr_index = dep.get('index')
+                        if jsonpath_expr:
+                            replace_value = f'self.cache.get_by_jsonpath("{var}",jsonpath_expr="{jsonpath_expr}")'
+                            if expr_index is not None:
+                                replace_value = f'self.cache.get_by_jsonpath("{var}",jsonpath_expr="{jsonpath_expr}", expr_index={expr_index})'
+                        else:
+                            replace_value = f'self.cache.get({var.get()})'
+                        data = data.replace(f"'{replace_mark}'", replace_value)
+            data = data.replace('"{', '{').replace('}"', "}")
+            data = data.replace('"self.', 'self.').replace(')"', ')')
+            data = data.replace('"test_data', 'test_data').replace(']"', ']')
 
-            else:
-                # 处理公共参数
-                replace_value = f'getattr(self.pp, "{replace_value}")'
-            data = data.replace(f"'{replace_mark}'", replace_value)
-        data = data.replace('"{', '{', 1).replace('}"', "}", 1)
         return data
 
 
@@ -356,6 +363,20 @@ def init_yaml_parse(file_path: Text):
     return yp
 
 
+def remove_dependent_api(ao_list: list) -> list:
+    """在测试步骤接口列表中，去除被依赖的接口"""
+    dep_apis = []
+    for ao in ao_list:
+        dependent_api_list = ao.get("dependent_api")
+        if dependent_api_list is not None:
+            for dependent_api in dependent_api_list:
+                _, dep_module = dependent_api.get('module').split(".")
+                x = {"module": dep_module, "api": dependent_api["api"]}
+                if x not in dep_apis:
+                    dep_apis.append(x)
+    return dep_apis
+
+
 if __name__ == '__main__':
-    yml = YamlParse('../hpc.yaml')
-    yml.make_testcase_file()
+    yml = YamlParse(r'D:\项目列表\aomaker\ehpc\hpc.yaml')
+    yml.make_ao_file()
